@@ -7,7 +7,7 @@ from .collators import MAEFinetuneMixCollator
 # datasets
 from .datasets.kd_image_folder import KDImageFolder
 # transforms
-from .transforms import BYOLTransform0, BYOLTransform1
+from .transforms import BYOLTransform, BYOLTransform0, BYOLTransform1
 from .transforms import MAEFinetuneTransform
 from .transforms.norm.kd_cifar100_norm import KDCifar100Norm
 # norm
