@@ -32,9 +32,8 @@ class KDImageFolder(KDDataset):
     def getitem_class(self, idx, ctx=None):
         return self.dataset.targets[idx]
 
-    @property
-    def n_classes(self):
-        return len(self.dataset.classes)
+    def getshape_class(self):
+        return len(self.dataset.classes),
 
     def __len__(self):
         return len(self.dataset)
