@@ -1,5 +1,5 @@
 # transforms
-from .byol_transforms import BYOLTransform0, BYOLTransform1
+from .byol_transforms import BYOLTransform, BYOLTransform0, BYOLTransform1
 from .imagenet_minaug_transforms import ImagenetMinaugTransform
 from .imagenet_noaug_transforms import ImagenetNoaugTransform
 from .mae_finetune_transform import MAEFinetuneTransform
