@@ -12,7 +12,7 @@ class LabelSmoothingWrapper(KDWrapper):
     def getitem_class(self, idx, ctx=None):
         y = self.dataset.getitem_class(idx, ctx)
         assert isinstance(y, int) or (torch.is_tensor(y) and y.ndim == 0)
-        n_classes = self.dataset.n_classes
+        n_classes = self.dataset.getdim_class()
         off_value = self.smoothing / n_classes
         on_value = 1. - self.smoothing + off_value
         y_vector = torch.full(size=(n_classes,), fill_value=off_value)
